﻿Imports ThinkGeo.MapSuite.Core
Imports System.Collections.ObjectModel

Namespace MapShapes
    Class MapShapeLayer
        Inherits Layer
        Private m_mapShapes As Dictionary(Of String, MapShape)

        Public Sub New()
            m_mapShapes = New Dictionary(Of String, MapShape)()
        End Sub

        ' Here is where you place all of your map shapes.
        Public ReadOnly Property MapShapes() As Dictionary(Of String, MapShape)
            Get
                Return m_mapShapes
            End Get
        End Property

        ' This is a required overload of the Layer.  As you can see we simply
        ' loop through all of our map shapes and then choose the correct zoom level.
        ' After that, the zoom level class takes care of the heavy lifiting.  You
        ' have to love how easy this framework is to re-use.

        Protected Overrides Sub DrawCore(ByVal canvas As GeoCanvas, ByVal labelsInAllLayers As Collection(Of SimpleCandidate))
            For Each mapShapeKey As String In m_mapShapes.Keys
                Dim mapShape As MapShape = m_mapShapes(mapShapeKey)
                Dim currentZoomLevel As ZoomLevel = mapShape.ZoomLevels.GetZoomLevelForDrawing(canvas.CurrentWorldExtent, canvas.Width, GeographyUnit.DecimalDegree)
                If currentZoomLevel IsNot Nothing Then
                    If canvas.CurrentWorldExtent.Intersects(mapShape.Feature.GetBoundingBox()) Then
                        currentZoomLevel.Draw(canvas, New Feature() {mapShape.Feature}, New Collection(Of SimpleCandidate)(), labelsInAllLayers)
                    End If
                End If
            Next
        End Sub
    End Class
End Namespace